Index: /FCKeditor/trunk/_whatsnew.html
===================================================================
--- /FCKeditor/trunk/_whatsnew.html	(revision 2570)
+++ /FCKeditor/trunk/_whatsnew.html	(revision 2571)
@@ -91,4 +91,6 @@
 		<li>[<a target="_blank" href="http://dev.fckeditor.net/ticket/2516">#2516</a>] Replaced the
 			extension AddItem of Array with the standard "push" method.</li>
+		<li>[<a target="_blank" href="http://dev.fckeditor.net/ticket/2486">#2486</a>] Vertically splitting
+			cell with colspan > 1 breaks table layout.</li> 			
 	</ul>
 	<p>
Index: /FCKeditor/trunk/editor/_source/internals/fcktablehandler.js
===================================================================
--- /FCKeditor/trunk/editor/_source/internals/fcktablehandler.js	(revision 2570)
+++ /FCKeditor/trunk/editor/_source/internals/fcktablehandler.js	(revision 2571)
@@ -518,4 +518,6 @@
 	var currentRowIndex = currentCell.parentNode.rowIndex ;
 	var cellIndex = FCKTableHandler._GetCellIndexSpan( tableMap, currentRowIndex, currentCell ) ;
+	// Save current cell colSpan
+	var currentColSpan = isNaN( currentCell.colSpan ) ? 1 : currentCell.colSpan ;	
 	var currentRowSpan = currentCell.rowSpan ;
 	if ( isNaN( currentRowSpan ) )
@@ -540,7 +542,9 @@
 		}
 
 		// 3. Insert the new cell to the indicated place, with the appropriate rowSpan, next row.
 		var newCell = FCK.EditorDocument.createElement( currentCell.nodeName ) ;
 		newCell.rowSpan = Math.floor( currentRowSpan / 2 ) ;
+		if ( currentColSpan > 1 )
+			newCell.colSpan = currentColSpan ;
 		if ( FCKBrowserInfo.IsGeckoLike )
 			FCKTools.AppendBogusBr( newCell ) ;
@@ -576,6 +580,8 @@
 		}
 
 		// 3. Insert a new cell to new row.
 		var newCell = FCK.EditorDocument.createElement( currentCell.nodeName ) ;
+		if ( currentColSpan > 1 )
+			newCell.colSpan = currentColSpan ;		
 		if ( FCKBrowserInfo.IsGeckoLike )
 			FCKTools.AppendBogusBr( newCell	) ;
@@ -540,7 +542,9 @@
 		}
 
-		// 3. Insert the new cell to the indicated place, with the appropriate rowSpan, next row.
+		// 3. Insert the new cell to the indicated place, with the appropriate rowSpan and colSpan, next row.
 		var newCell = FCK.EditorDocument.createElement( currentCell.nodeName ) ;
 		newCell.rowSpan = Math.floor( currentRowSpan / 2 ) ;
@@ -576,6 +580,8 @@
 		}
 
-		// 3. Insert a new cell to new row.
+		// 3. Insert a new cell to new row. Set colSpan on the new cell.
 		var newCell = FCK.EditorDocument.createElement( currentCell.nodeName ) ;
